@@ -106,6 +106,7 @@ Data::Data(const kodi::addon::IInstanceInfo& instance)
     , GetInstanceSettingString("password")
     , GetInstanceSettingString("deviceId")
     , GetInstanceSettingString("productId")
+    , GetInstanceSettingString("userAgent")
     , instance.GetNumber()
   }
 {
@@ -118,13 +119,15 @@ Data::Data(const kodi::addon::IInstanceInfo& instance)
 
   m_streamQuality = GetInstanceSettingEnum<ApiManager::StreamQuality_t>("streamQuality", ApiManager::SQ_DEFAULT);
   m_fullChannelEpgRefresh = GetInstanceSettingInt("fullChannelEpgRefresh", 24) * 3600; // make it seconds
-  m_loadingsRefresh = GetInstanceSettingInt("loadingsRefresh", 60);
-  m_keepAliveDelay = GetInstanceSettingInt("keepAliveDelay", 20);
-  m_epgCheckDelay = GetInstanceSettingInt("epgCheckDelay", 1) * 60; // make it seconds
+  m_loadingsRefresh = GetInstanceSettingInt("loadingsRefresh", 10) * 60; // make it seconds
+  m_keepAliveDelay = GetInstanceSettingInt("keepAliveDelay", 120) * 60;  // make it seconds
+  m_epgCheckDelay = GetInstanceSettingInt("epgCheckDelay", 10) * 60; // make it seconds
   m_useH265 = GetInstanceSettingBoolean("useH265", false);
   m_useAdaptive = GetInstanceSettingBoolean("useAdaptive", false);
   m_showLockedChannels = GetInstanceSettingBoolean("showLockedChannels", true);
   m_showLockedOnlyPin = GetInstanceSettingBoolean("showLockedOnlyPin", true);
+  kodi::Log(ADDON_LOG_DEBUG, "loadingsRefresh: %d, keepAliveDelay: %d, epgCheckDelay: %d, useHa265: %d, useAdaptive: %d, showLockedChannels: %d, showLockedOnlyPin: %d"
+      , m_loadingsRefresh, m_keepAliveDelay, m_epgCheckDelay, m_useH265, m_useAdaptive, m_showLockedChannels, m_showLockedOnlyPin);
 
   m_thread = std::thread{[this] { Process(); }};
 }
@@ -695,24 +698,12 @@ bool Data::LoadRecordings()
   {
     const auto & old_rec = (*recordings)[i];
     const auto & new_rec = (*new_recordings)[i];
-    if (new_rec.strRecordId != old_rec.strRecordId || new_rec.strStreamUrl != old_rec.strStreamUrl)
+    if (new_rec.strRecordId != old_rec.strRecordId)
     {
       changed_r = true;
       break;
     }
   }
-  if (changed_r)
-  {
-    for (auto & recording : *new_recordings)
-    {
-      std::string channel_id;
-      bool isDrm;
-      recording.strStreamUrl = m_manager.getRecordingUrl(recording.strRecordId, channel_id, isDrm);
-      // get the stream type based on channel
-      recording.strStreamType = ChannelStreamType(channel_id);
-      recording.bIsDrm = isDrm;
-    }
-  }
   bool changed_t = new_timers->size() != timers->size();
   for (size_t i = 0; !changed_t && i < new_timers->size(); ++i)
   {
@@ -1239,9 +1230,10 @@ PVR_ERROR Data::GetRecordingStreamUrl(const std::string & recording, std::string
   if (!PinCheckUnlock(rec_i->bIsPinLocked, unlocked_now))
     return PVR_ERROR_REJECTED;
 
-  streamUrl = rec_i->strStreamUrl;
-  streamType = rec_i->strStreamType;
-  isDrm = rec_i->bIsDrm;
+  std::string channel_id;
+  streamUrl = m_manager.getRecordingUrl(rec_i->strRecordId, channel_id, isDrm);
+  // get the stream type based on channel
+  streamType = ChannelStreamType(channel_id);
   return PVR_ERROR_NO_ERROR;
 }
 
@@ -1413,6 +1405,7 @@ std::vector<kodi::addon::PVRStreamProperty> Data::StreamProperties(const std::st
   if (m_useAdaptive && 0 < ADAPTIVE_TYPES.count(streamType))
   {
     properties.emplace_back(PVR_STREAM_PROPERTY_INPUTSTREAM, "inputstream.adaptive");
+    properties.emplace_back("inputstream.adaptive.live_delay", "30");
     if (isDrm)
     {
       decltype (m_drmCertificate) certificate;
